@@ -2,6 +2,7 @@
 
 # 2010-09-04: J. Fox: changed color choice
 # 2010-09-16: fixed point color when col is length 1
+# 2011-03-08: J. Fox: changed col argument
 
 scatterplotMatrix <- function(x, ...){
 	UseMethod("scatterplotMatrix")
@@ -48,7 +49,7 @@ scatterplotMatrix.default <- function(x, var.labels=colnames(x),
 	ellipse=FALSE, levels=c(.5, .95), robust=TRUE,
 	groups=NULL, by.groups=FALSE, 
 	labels, id.method="mahal", id.n=0, id.cex=1, id.col=palette()[1],
-	col=if (n.groups == 1) palette()[2:1] else rep(palette(), length=n.groups),
+	col=if (n.groups == 1) palette()[3:1] else rep(palette(), length=n.groups),
 	pch=1:n.groups, lwd=1, lwd.smooth=lwd, lwd.spread=lwd, lty=1, lty.smooth=lty, lty.spread=2,
 	cex=par("cex"), cex.axis=par("cex.axis"), cex.labels=NULL, 
 	cex.main=par("cex.main"), 
@@ -142,13 +143,13 @@ scatterplotMatrix.default <- function(x, var.labels=colnames(x),
 	}
 	panel.histogram <- function(x, ...){
 		par(new=TRUE)
-		hist(x, main="", axes=FALSE, breaks=nclass, col=col[2])
+		hist(x, main="", axes=FALSE, breaks=nclass, col=col[1])
 		if (do.legend) legendPlot()
 		do.legend <<- FALSE
 	}
 	panel.boxplot <- function(x, ...){
 		par(new=TRUE)
-		boxplot(x, axes=FALSE, main="", col=col[2])
+		boxplot(x, axes=FALSE, main="", col=col[1])
 		if (do.legend) legendPlot()
 		do.legend <<- FALSE
 	}
@@ -157,14 +158,14 @@ scatterplotMatrix.default <- function(x, var.labels=colnames(x),
 		range <- range(x)
 		delta <- diff(range)/50
 		y <- mean(range)
-		segments(x - delta, x, x + delta, x, col = col[1])
+		segments(x - delta, x, x + delta, x, col = col[3])
 		if (do.legend) legendPlot()
 		do.legend <<- FALSE
 	}
 	panel.qqplot <- function(x, ...){
 		par(new=TRUE)
-		qqnorm(x, axes=FALSE, xlab="", ylab="", main="", col=col[1])
-		qqline(x)
+		qqnorm(x, axes=FALSE, xlab="", ylab="", main="", col=col[3])
+		qqline(x, col=col[1])
 		if (do.legend) legendPlot()
 		do.legend <<- FALSE
 	}
@@ -178,7 +179,7 @@ scatterplotMatrix.default <- function(x, var.labels=colnames(x),
 	groups <- as.factor(if(missing(groups)) rep(1, length(x[, 1])) else groups)
 	n.groups <- length(levels(groups))
 	if (n.groups > length(col)) stop("number of groups exceeds number of available colors")
-	if (length(col) == 1) col <- rep(col, 2)
+	if (length(col) == 1) col <- rep(col, 3)
 	if (transform != FALSE | length(transform) == ncol(x)){
 		if (transform == TRUE & length(transform) == 1){
 			transform <- if (by.groups) coef(powerTransform(as.matrix(x) ~ groups, family=family), round=TRUE)
@@ -198,7 +199,7 @@ scatterplotMatrix.default <- function(x, var.labels=colnames(x),
 		panel=function(x, y, ...){ 
 			for (i in 1:n.groups){
 				subs <- groups == levels(groups)[i]
-				if (plot.points) points(x[subs], y[subs], pch=pch[i], col=col[if (n.groups == 1) 2 else i], cex=cex)
+				if (plot.points) points(x[subs], y[subs], pch=pch[i], col=col[if (n.groups == 1) 3 else i], cex=cex)
 				if (by.groups){
 					if (smooth) lowess.line(x[subs], y[subs], col=col[i], span)
 					if (is.function(reg.line)) reg(x[subs], y[subs], col=col[i])
@@ -212,8 +213,8 @@ scatterplotMatrix.default <- function(x, var.labels=colnames(x),
 				}
 			}
 			if (!by.groups){
-				if (is.function(reg.line)) abline(reg.line(y ~ x), lty=lty, lwd=lwd, col=col[2])
-				if (smooth) lowess.line(x, y, col=col[1], span)
+				if (is.function(reg.line)) abline(reg.line(y ~ x), lty=lty, lwd=lwd, col=col[1])
+				if (smooth) lowess.line(x, y, col=col[2], span)
 				if (ellipse) dataEllipse(x, y, plot.points=FALSE, levels=levels, col=col[1],
 						robust=robust, lwd=1)
 				showLabels(x, y, labs, id.method=id.method, 
